aboutsummaryrefslogtreecommitdiff
path: root/lib/application-service/definitions/location.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/application-service/definitions/location.h')
-rw-r--r--lib/application-service/definitions/location.h41
1 files changed, 22 insertions, 19 deletions
diff --git a/lib/application-service/definitions/location.h b/lib/application-service/definitions/location.h
index 5586cfc6..77512514 100644
--- a/lib/application-service/definitions/location.h
+++ b/lib/application-service/definitions/location.h
@@ -8,23 +8,26 @@
#include <QtCore/QJsonObject>
-namespace QMatrixClient
+namespace Quotient
{
- // Data structures
-
- struct ThirdPartyLocation
- {
- /// An alias for a matrix room.
- QString alias;
- /// The protocol ID that the third party location is a part of.
- QString protocol;
- /// Information used to identify this third party location.
- QJsonObject fields;
- };
- template <> struct JsonObjectConverter<ThirdPartyLocation>
- {
- static void dumpTo(QJsonObject& jo, const ThirdPartyLocation& pod);
- static void fillFrom(const QJsonObject& jo, ThirdPartyLocation& pod);
- };
-
-} // namespace QMatrixClient
+
+// Data structures
+
+struct ThirdPartyLocation
+{
+ /// An alias for a matrix room.
+ QString alias;
+ /// The protocol ID that the third party location is a part of.
+ QString protocol;
+ /// Information used to identify this third party location.
+ QJsonObject fields;
+};
+
+template <>
+struct JsonObjectConverter<ThirdPartyLocation>
+{
+ static void dumpTo(QJsonObject& jo, const ThirdPartyLocation& pod);
+ static void fillFrom(const QJsonObject& jo, ThirdPartyLocation& pod);
+};
+
+} // namespace Quotient